@@ -6,20 +6,24 @@
 # rescale function in his arm package.                                    #
 ###########################################################################
 
-CenterScale <- function(x, binary=NULL)
+CenterScale <- function(x, Binary=c("none", "center", "center0",
+     "centerscale"))
      {
      ### Initial Checks
      if(!is.numeric(x)){
           x <- as.numeric(factor(x))
           x.obs <- x[!is.na(x)]}
      x.obs <- x[!is.na(x)]
+     if(is.null(Binary)) Binary="none"
      ### Binary Variables
      if(length(unique(x.obs)) == 2){
-          if(is.null(binary)){
+          if(Binary == "none"){
                return((x-min(x.obs)) / (max(x.obs)-min(x.obs)))}
-          else if(binary == "center0") {return (x-0.5)}
-          else if(binary == "center") {return (x-mean(x.obs))}
-          else if(binary == "centerscale") {
+          else if(Binary == "center") {return (x-mean(x.obs))}
+          else if(Binary == "center0") {
+               x <- (x-min(x.obs)) / (max(x.obs)-min(x.obs))
+               return (x-0.5)}
+          else if(Binary == "centerscale") {
                return ((x-mean(x.obs)) / (2*sd(x.obs)))}
           }
      ### Continuous Variables
