@@ -1,6 +1,6 @@
 .onLoad <- function(libname, pkgname) {
      cat("\nLaplacesDemon: Software for Bayesian Inference\n\n")
      cat("``Probability theory is nothing but common sense reduced to \n")
-     cat("calculation'' (Pierre-Simon Laplace).\n\n")
+     cat("calculation'' (Pierre-Simon Laplace, 1814).\n\n")
      cat("Laplace's Demon is ready for you.\n\n")
 }
